==> order-center-api-2.0.9-CLOUD-DEV-20220527.071304-5-sources.jar: com/tydic/dyc/oc/service/cmporder/bo/UocGetCmpOrderDetailServiceRspDetailBo.java <==
package com.tydic.dyc.oc.service.cmporder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题：类名称:UocGetCmpOrderDetailServiceReqItemBo
 * 说明：描述一下类的作用TODO
 * 时间：2022/3/29 14:06
 * 作者 @author 尹栋梁
 */
@Data
public class UocGetCmpOrderDetailServiceRspDetailBo implements Serializable {

    private static final long serialVersionUID = -1090406175596509326L;
    @DocField(value = "比选单id")
    private Long cmpOrderId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "比选单号")
    private String cmpOrderNo;

    @DocField(value = "订单状态")
    private String cmpOrderState;

    @DocField(value = "比选单来源")
    private Integer cmpOrderSource;

    @DocField(value = "租户ID")
    private String tenantId;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建时间 开始")
    private Date createTimeStart;

    @DocField(value = "创建时间 结束")
    private Date createTimeEnd;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "创建人名称")
    private String createOperName;

    @DocField(value = "机构id")
    private String createOrgId;

    @DocField(value = "机构名称")
    private String createOrgName;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新时间 开始")
    private Date updateTimeStart;

    @DocField(value = "更新时间 结束")
    private Date updateTimeEnd;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "商品图")
    private String skuMainPicUrl;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "排序")
    private String orderBy;

    @DocField(value = "比选明细表")
    private List<UocGetCmpOrderDetailServiceRspItemBo> uocCmpOrderItemList;

    @DocField(value = "格式化比选明细")
    private List<UocGetCmpOrderDetailServiceRspItemBo> uocCmpOrderItemFormatList;

    @DocField(value = "比选物料表")
    private List<UocGetCmpOrderDetailServiceRspMaterialBo> uocCmpMaterialList;

    @DocField(value = "比选供应商")
    private List<UocGetCmpOrderDetailServiceRspSupplierBo> uocCmpSupplierList;

    @DocField(value = "比选单扩展")
    private List<UocGetCmpOrderDetailServiceRspMapBo> uocCmpOrderMapList;

    @DocField(value = "比选价格")
    private List<UocGetCmpOrderDetailServiceRspSalePriceBo> uocCmpSalePriceList;
}

==> order-center-api-3.1.0-CLOUD-DEV-20230801.034020-62-sources.jar: com/tydic/dyc/oc/service/cmporder/bo/UocGetCmpOrderDetailServiceRspDetailBo.java <==
package com.tydic.dyc.oc.service.cmporder.bo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题：类名称:UocGetCmpOrderDetailServiceReqItemBo
 * 说明：描述一下类的作用TODO
 * 时间：2022/3/29 14:06
 * 作者 @author 尹栋梁
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetCmpOrderDetailServiceRspDetailBo implements Serializable {

    private static final long serialVersionUID = -1090406175596509326L;
    /**
     * 比选单id
     */
    private Long cmpOrderId;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 比选单号
     */
    private String cmpOrderNo;

    /**
     * 订单状态
     */
    private String cmpOrderState;

    /**
     * 比选单来源
     */
    private Integer cmpOrderSource;

    /**
     * 租户ID
     */
    private String tenantId;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 创建时间 开始
     */
    private Date createTimeStart;

    /**
     * 创建时间 结束
     */
    private Date createTimeEnd;

    /**
     * 创建工号
     */
    private String createOperId;

    /**
     * 创建人名称
     */
    private String createOperName;

    /**
     * 机构id
     */
    private String createOrgId;

    /**
     * 机构名称
     */
    private String createOrgName;

    /**
     * 更新时间
     */
    private Date updateTime;

    /**
     * 更新时间 开始
     */
    private Date updateTimeStart;

    /**
     * 更新时间 结束
     */
    private Date updateTimeEnd;

    /**
     * 更新工号
     */
    private String updateOperId;

    /**
     * 备注
     */
    private String remark;

    /**
     * 商品图
     */
    private String skuMainPicUrl;

    /**
     * 删除标志1已删除
     */
    private Integer delTag;

    /**
     * 排序
     */
    private String orderBy;

    /**
     * 比选明细表
     */
    private List<UocGetCmpOrderDetailServiceRspItemBo> uocCmpOrderItemList;

    /**
     * 格式化比选明细
     */
    private List<UocGetCmpOrderDetailServiceRspItemFormatBo> uocCmpOrderItemFormatList;

    /**
     * 比选物料表
     */
    private List<UocGetCmpOrderDetailServiceRspMaterialBo> uocCmpMaterialList;

    /**
     * 比选供应商
     */
    private List<UocGetCmpOrderDetailServiceRspSupplierBo> uocCmpSupplierList;

    /**
     * 比选单扩展
     */
    private List<UocGetCmpOrderDetailServiceRspMapBo> uocCmpOrderMapList;

    /**
     * 比选价格
     */
    private List<UocGetCmpOrderDetailServiceRspSalePriceBo> uocCmpSalePriceList;
    
    /**
     * 比选单快照
     */
    private String cmpSnapshot;
}
